@@ -14,15 +14,20 @@
 #include "anim.h"
 #include "main.h"
 #include "tools.h"
+#include "files.h"
 #include "events.h"
 #include "screens.h"
 
 
-/* values for global toon animation definition */
+#define DEBUG_ANIM_DELAY		0
+#define DEBUG_ANIM_EVENTS		0
+
+
+// values for global toon animation definition
 #define NUM_GLOBAL_TOON_ANIMS		1
 #define NUM_GLOBAL_TOON_PARTS		MAX_NUM_TOONS
 
-/* values for global animation definition (including toons) */
+// values for global animation definition (including toons)
 #define NUM_GLOBAL_ANIMS_AND_TOONS	(NUM_GLOBAL_ANIMS +		\
 					 NUM_GLOBAL_TOON_ANIMS)
 #define NUM_GLOBAL_ANIM_PARTS_AND_TOONS	MAX(NUM_GLOBAL_ANIM_PARTS_ALL,	\
@@ -35,8 +40,9 @@
 #define ANIM_CLASS_BIT_SUBMENU		4
 #define ANIM_CLASS_BIT_MENU		5
 #define ANIM_CLASS_BIT_TOONS		6
+#define ANIM_CLASS_BIT_NO_TITLE		7
 
-#define NUM_ANIM_CLASSES		7
+#define NUM_ANIM_CLASSES		8
 
 #define ANIM_CLASS_NONE			0
 #define ANIM_CLASS_TITLE_INITIAL	(1 << ANIM_CLASS_BIT_TITLE_INITIAL)
@@ -46,25 +52,29 @@
 #define ANIM_CLASS_SUBMENU		(1 << ANIM_CLASS_BIT_SUBMENU)
 #define ANIM_CLASS_MENU			(1 << ANIM_CLASS_BIT_MENU)
 #define ANIM_CLASS_TOONS		(1 << ANIM_CLASS_BIT_TOONS)
+#define ANIM_CLASS_NO_TITLE		(1 << ANIM_CLASS_BIT_NO_TITLE)
 
-#define ANIM_CLASS_TOONS_SCORES		(ANIM_CLASS_TOONS |	\
-					 ANIM_CLASS_SCORES)
+#define ANIM_CLASS_TOONS_SCORES		(ANIM_CLASS_TOONS 	|	\
+					 ANIM_CLASS_SCORES	|	\
+					 ANIM_CLASS_NO_TITLE)
 
-#define ANIM_CLASS_TOONS_MENU_MAIN	(ANIM_CLASS_TOONS |	\
-					 ANIM_CLASS_MENU  |	\
-					 ANIM_CLASS_MAIN)
+#define ANIM_CLASS_TOONS_MENU_MAIN	(ANIM_CLASS_TOONS 	|	\
+					 ANIM_CLASS_MENU  	|	\
+					 ANIM_CLASS_MAIN  	|	\
+					 ANIM_CLASS_NO_TITLE)
 
-#define ANIM_CLASS_TOONS_MENU_SUBMENU	(ANIM_CLASS_TOONS |	\
-					 ANIM_CLASS_MENU  |	\
-					 ANIM_CLASS_SUBMENU)
+#define ANIM_CLASS_TOONS_MENU_SUBMENU	(ANIM_CLASS_TOONS 	|	\
+					 ANIM_CLASS_MENU  	|	\
+					 ANIM_CLASS_SUBMENU	|	\
+					 ANIM_CLASS_NO_TITLE)
 
-/* values for global animation states */
+// values for global animation states
 #define ANIM_STATE_INACTIVE		0
 #define ANIM_STATE_RESTART		(1 << 0)
 #define ANIM_STATE_WAITING		(1 << 1)
 #define ANIM_STATE_RUNNING		(1 << 2)
 
-/* values for global animation control */
+// values for global animation control
 #define ANIM_NO_ACTION			0
 #define ANIM_START			1
 #define ANIM_CONTINUE			2
@@ -98,6 +108,7 @@ struct GlobalAnimPartControlInfo
   int step_xoffset, step_yoffset;
 
   unsigned int initial_anim_sync_frame;
+  unsigned int anim_random_frame;
   unsigned int step_delay, step_delay_value;
 
   int init_delay_counter;
@@ -107,6 +118,7 @@ struct GlobalAnimPartControlInfo
   boolean init_event_state;
   boolean anim_event_state;
 
+  boolean triggered;
   boolean clickable;
   boolean clicked;
 
@@ -174,6 +186,8 @@ struct GameModeAnimClass
   { GAME_MODE_PSEUDO_TYPENAME,		ANIM_CLASS_TOONS_MENU_MAIN	},
   { GAME_MODE_PSEUDO_SCORESOLD,		ANIM_CLASS_TOONS_SCORES		},
   { GAME_MODE_PSEUDO_SCORESNEW,		ANIM_CLASS_TOONS_SCORES		},
+  { GAME_MODE_EDITOR,			ANIM_CLASS_NO_TITLE		},
+  { GAME_MODE_PLAYING,			ANIM_CLASS_NO_TITLE		},
 
   { -1,					-1				}
 };
@@ -191,11 +205,14 @@ struct AnimClassGameMode
   { ANIM_CLASS_BIT_SUBMENU,		GAME_MODE_PSEUDO_SUBMENU	},
   { ANIM_CLASS_BIT_MENU,		GAME_MODE_PSEUDO_MENU		},
   { ANIM_CLASS_BIT_TOONS,		GAME_MODE_PSEUDO_TOONS		},
+  { ANIM_CLASS_BIT_NO_TITLE,		GAME_MODE_PSEUDO_NO_TITLE	},
 
   { -1,					-1				}
 };
 
-/* forward declaration for internal use */
+// forward declaration for internal use
+static void DoGlobalAnim_DelayAction(struct GlobalAnimPartControlInfo *, int);
+static boolean DoGlobalAnim_EventAction(struct GlobalAnimPartControlInfo *);
 static void HandleGlobalAnim(int, int);
 static void DoAnimationExt(void);
 static void ResetGlobalAnim_Clickable(void);
@@ -214,46 +231,51 @@ static int anim_classes_last = ANIM_CLASS_NONE;
 
 static boolean drawing_to_fading_buffer = FALSE;
 
+static boolean handle_click = FALSE;
 
-/* ========================================================================= */
-/* generic animation frame calculation                                       */
-/* ========================================================================= */
+
+// ============================================================================
+// generic animation frame calculation
+// ============================================================================
 
 int getAnimationFrame(int num_frames, int delay, int mode, int start_frame,
 		      int sync_frame)
 {
   int frame = 0;
 
+  if (delay < 1)			// delay must be at least 1
+    delay = 1;
+
   sync_frame += start_frame * delay;
 
-  if (mode & ANIM_LOOP)			/* looping animation */
+  if (mode & ANIM_LOOP)			// looping animation
   {
     frame = (sync_frame % (delay * num_frames)) / delay;
   }
-  else if (mode & ANIM_LINEAR)		/* linear (non-looping) animation */
+  else if (mode & ANIM_LINEAR)		// linear (non-looping) animation
   {
     frame = sync_frame / delay;
 
     if (frame > num_frames - 1)
       frame = num_frames - 1;
   }
-  else if (mode & ANIM_PINGPONG)	/* oscillate (border frames once) */
+  else if (mode & ANIM_PINGPONG)	// oscillate (border frames once)
   {
     int max_anim_frames = (num_frames > 1 ? 2 * num_frames - 2 : 1);
 
     frame = (sync_frame % (delay * max_anim_frames)) / delay;
     frame = (frame < num_frames ? frame : max_anim_frames - frame);
   }
-  else if (mode & ANIM_PINGPONG2)	/* oscillate (border frames twice) */
+  else if (mode & ANIM_PINGPONG2)	// oscillate (border frames twice)
   {
     int max_anim_frames = 2 * num_frames;
 
     frame = (sync_frame % (delay * max_anim_frames)) / delay;
     frame = (frame < num_frames ? frame : max_anim_frames - frame - 1);
   }
-  else if (mode & ANIM_RANDOM)		/* play frames in random order */
+  else if (mode & ANIM_RANDOM)		// play frames in random order
   {
-    /* note: expect different frames for the same delay cycle! */
+    // note: expect different frames for the same delay cycle!
 
     if (gfx.anim_random_frame < 0)
       frame = GetSimpleRandom(num_frames);
@@ -265,16 +287,16 @@ int getAnimationFrame(int num_frames, int delay, int mode, int start_frame,
     frame = sync_frame % num_frames;
   }
 
-  if (mode & ANIM_REVERSE)		/* use reverse animation direction */
+  if (mode & ANIM_REVERSE)		// use reverse animation direction
     frame = num_frames - frame - 1;
 
   return frame;
 }
 
 
-/* ========================================================================= */
-/* global animation functions                                                */
-/* ========================================================================= */
+// ============================================================================
+// global animation functions
+// ============================================================================
 
 static int getGlobalAnimationPart(struct GlobalAnimMainControlInfo *anim)
 {
@@ -391,6 +413,7 @@ static void InitToonControls(void)
     part->control_info.y = ARG_UNDEFINED_VALUE;
 
     part->initial_anim_sync_frame = 0;
+    part->anim_random_frame = -1;
 
     part->step_delay = 0;
     part->step_delay_value = graphic_info[control].step_delay;
@@ -495,6 +518,7 @@ static void InitGlobalAnimControls(void)
 	part->control_info = graphic_info[control];
 
 	part->initial_anim_sync_frame = 0;
+	part->anim_random_frame = -1;
 
 	part->step_delay = 0;
 	part->step_delay_value = graphic_info[control].step_delay;
@@ -518,6 +542,20 @@ static void InitGlobalAnimControls(void)
 	  anim->base = *part;
 	  anim->has_base = TRUE;
 	}
+
+	// apply special settings for pointer-style animations
+	if (part->control_info.class == get_hash_from_key("pointer"))
+	{
+	  // force animation to be on top (must set anim and part control)
+	  if (anim->control_info.draw_order == 0)
+	    anim->control_info.draw_order = 1000000;
+	  if (part->control_info.draw_order == 0)
+	    part->control_info.draw_order = 1000000;
+
+	  // force animation to pass-through clicks (must set part control)
+	  if (part->control_info.style == STYLE_DEFAULT)
+	    part->control_info.style |= STYLE_PASSTHROUGH;
+	}
       }
 
       if (anim->num_parts > 0 || anim->has_base)
@@ -530,12 +568,12 @@ static void InitGlobalAnimControls(void)
 
   InitToonControls();
 
-  /* sort all animations according to draw_order and animation number */
+  // sort all animations according to draw_order and animation number
   for (m = 0; m < NUM_GAME_MODES; m++)
   {
     struct GlobalAnimControlInfo *ctrl = &global_anim_ctrl[m];
 
-    /* sort all main animations for this game mode */
+    // sort all main animations for this game mode
     qsort(ctrl->anim, ctrl->num_anims,
 	  sizeof(struct GlobalAnimMainControlInfo),
 	  compareGlobalAnimMainControlInfo);
@@ -544,7 +582,7 @@ static void InitGlobalAnimControls(void)
     {
       struct GlobalAnimMainControlInfo *anim = &ctrl->anim[a];
 
-      /* sort all animation parts for this main animation */
+      // sort all animation parts for this main animation
       qsort(anim->part, anim->num_parts,
 	    sizeof(struct GlobalAnimPartControlInfo),
 	    compareGlobalAnimPartControlInfo);
@@ -732,6 +770,7 @@ static void DrawGlobalAnimationsExt(int drawing_target, int drawing_stage)
 	  (g->draw_masked ? BlitBitmapMasked : BlitBitmap);
 	void (*blit_screen)(Bitmap *, int, int, int, int, int, int) =
 	  (g->draw_masked ? BlitToScreenMasked : BlitToScreen);
+	int last_anim_random_frame = gfx.anim_random_frame;
 
 	if (!(part->state & ANIM_STATE_RUNNING))
 	  continue;
@@ -764,10 +803,21 @@ static void DrawGlobalAnimationsExt(int drawing_target, int drawing_stage)
 	dst_y += part->viewport_y;
 
 	sync_frame = anim_sync_frame - part->initial_anim_sync_frame;
+
+	// re-initialize random animation frame after animation delay
+	if (g->anim_mode == ANIM_RANDOM &&
+	    sync_frame % g->anim_delay == 0 &&
+	    sync_frame > 0)
+	  part->anim_random_frame = GetSimpleRandom(g->anim_frames);
+
+	gfx.anim_random_frame = part->anim_random_frame;
+
 	frame = getAnimationFrame(g->anim_frames, g->anim_delay,
 				  g->anim_mode, g->anim_start_frame,
 				  sync_frame);
 
+	gfx.anim_random_frame = last_anim_random_frame;
+
 	getFixedGraphicSource(part->graphic, frame, &src_bitmap,
 			      &src_x, &src_y);
 
@@ -797,13 +847,24 @@ static void DrawGlobalAnimationsExt(int drawing_target, int drawing_stage)
 
 void DrawGlobalAnimations(int drawing_target, int drawing_stage)
 {
+  int last_cursor_mode_override = gfx.cursor_mode_override;
+
   if (drawing_stage == DRAW_GLOBAL_ANIM_STAGE_1)
+  {
     ResetGlobalAnim_Clickable();
 
+    gfx.cursor_mode_override = CURSOR_UNDEFINED;
+  }
+
   DrawGlobalAnimationsExt(drawing_target, drawing_stage);
 
   if (drawing_stage == DRAW_GLOBAL_ANIM_STAGE_2)
+  {
     ResetGlobalAnim_Clicked();
+  }
+
+  if (gfx.cursor_mode_override != last_cursor_mode_override)
+    SetMouseCursor(gfx.cursor_mode);
 }
 
 static boolean SetGlobalAnimPart_Viewport(struct GlobalAnimPartControlInfo *part)
@@ -814,7 +875,8 @@ static boolean SetGlobalAnimPart_Viewport(struct GlobalAnimPartControlInfo *part
   int viewport_height;
   boolean changed = FALSE;
 
-  if (part->last_anim_status == global.anim_status)
+  if (part->last_anim_status == global.anim_status &&
+      part->control_info.class != get_hash_from_key("pointer"))
     return FALSE;
 
   part->last_anim_status = global.anim_status;
@@ -831,6 +893,27 @@ static boolean SetGlobalAnimPart_Viewport(struct GlobalAnimPartControlInfo *part
 
     part->drawing_stage = DRAW_GLOBAL_ANIM_STAGE_2;
   }
+  else if (part->control_info.class == get_hash_from_key("pointer"))
+  {
+    int mx = MIN(MAX(0, gfx.mouse_x), WIN_XSIZE - 1);
+    int my = MIN(MAX(0, gfx.mouse_y), WIN_YSIZE - 1);
+
+    // prevent displaying off-screen custom mouse cursor in upper left corner
+    if (gfx.mouse_x == POS_OFFSCREEN &&
+	gfx.mouse_y == POS_OFFSCREEN)
+      mx = my = POS_OFFSCREEN;
+
+    viewport_x = mx - part->control_info.x;
+    viewport_y = my - part->control_info.y;
+    viewport_width  = part->graphic_info.width;
+    viewport_height = part->graphic_info.height;
+
+    part->drawing_stage = DRAW_GLOBAL_ANIM_STAGE_2;
+
+    // do not use global animation mouse pointer when reloading artwork
+    if (global.anim_status != GAME_MODE_LOADING)
+      gfx.cursor_mode_override = CURSOR_NONE;
+  }
   else if (part->control_info.class == get_hash_from_key("door_1"))
   {
     viewport_x = DX;
@@ -840,10 +923,20 @@ static boolean SetGlobalAnimPart_Viewport(struct GlobalAnimPartControlInfo *part
   }
   else if (part->control_info.class == get_hash_from_key("door_2"))
   {
-    viewport_x = VX;
-    viewport_y = VY;
-    viewport_width  = VXSIZE;
-    viewport_height = VYSIZE;
+    if (part->mode_nr == GAME_MODE_EDITOR)
+    {
+      viewport_x = EX;
+      viewport_y = EY;
+      viewport_width  = EXSIZE;
+      viewport_height = EYSIZE;
+    }
+    else
+    {
+      viewport_x = VX;
+      viewport_y = VY;
+      viewport_width  = VXSIZE;
+      viewport_height = VYSIZE;
+    }
   }
   else		// default: "playfield"
   {
@@ -863,7 +956,8 @@ static boolean SetGlobalAnimPart_Viewport(struct GlobalAnimPartControlInfo *part
     part->viewport_width  = viewport_width;
     part->viewport_height = viewport_height;
 
-    changed = TRUE;
+    if (part->control_info.class != get_hash_from_key("pointer"))
+      changed = TRUE;
   }
 
   return changed;
@@ -981,23 +1075,45 @@ static void PlayGlobalAnimSoundIfLoop(struct GlobalAnimPartControlInfo *part)
   PlayGlobalAnimSound(part);
 }
 
+static boolean checkGlobalAnimEvent(int anim_event, int mask)
+{
+  int mask_anim_only = mask & ~ANIM_EVENT_PART_MASK;
+
+  if (mask & ANIM_EVENT_ANY)
+    return (anim_event & ANIM_EVENT_ANY);
+  else if (mask & ANIM_EVENT_SELF)
+    return (anim_event & ANIM_EVENT_SELF);
+  else if (mask & ANIM_EVENT_UNCLICK_ANY)
+    return (anim_event & ANIM_EVENT_UNCLICK_ANY);
+  else
+    return (anim_event == mask ||
+	    anim_event == mask_anim_only);
+}
+
 static boolean isClickablePart(struct GlobalAnimPartControlInfo *part, int mask)
 {
   struct GraphicInfo *c = &part->control_info;
-  int trigger_mask = ANIM_EVENT_ANIM_MASK | ANIM_EVENT_PART_MASK;
-  int mask_anim_only = mask & ANIM_EVENT_ANIM_MASK;
+  int num_init_events = GetGlobalAnimEventValueCount(c->init_event);
+  int num_anim_events = GetGlobalAnimEventValueCount(c->anim_event);
+  int i;
 
-  if (mask & ANIM_EVENT_ANY)
-    return (c->init_event & ANIM_EVENT_ANY ||
-	    c->anim_event & ANIM_EVENT_ANY);
-  else if (mask & ANIM_EVENT_SELF)
-    return (c->init_event & ANIM_EVENT_SELF ||
-	    c->anim_event & ANIM_EVENT_SELF);
-  else
-    return ((c->init_event & trigger_mask) == mask ||
-	    (c->anim_event & trigger_mask) == mask ||
-	    (c->init_event & trigger_mask) == mask_anim_only ||
-	    (c->anim_event & trigger_mask) == mask_anim_only);
+  for (i = 0; i < num_init_events; i++)
+  {
+    int init_event = GetGlobalAnimEventValue(c->init_event, i);
+
+    if (checkGlobalAnimEvent(init_event, mask))
+      return TRUE;
+  }
+
+  for (i = 0; i < num_anim_events; i++)
+  {
+    int anim_event = GetGlobalAnimEventValue(c->anim_event, i);
+
+    if (checkGlobalAnimEvent(anim_event, mask))
+      return TRUE;
+  }
+
+  return FALSE;
 }
 
 static boolean isClickedPart(struct GlobalAnimPartControlInfo *part,
@@ -1030,14 +1146,111 @@ static boolean isClickedPart(struct GlobalAnimPartControlInfo *part,
   return TRUE;
 }
 
+static boolean clickBlocked(struct GlobalAnimPartControlInfo *part)
+{
+  return (part->control_info.style & STYLE_BLOCK ? TRUE : FALSE);
+}
+
 static boolean clickConsumed(struct GlobalAnimPartControlInfo *part)
 {
   return (part->control_info.style & STYLE_PASSTHROUGH ? FALSE : TRUE);
 }
 
+static void InitGlobalAnim_Triggered(struct GlobalAnimPartControlInfo *part,
+				     boolean *click_consumed,
+				     boolean *any_event_action,
+				     int event_value, char *info_text)
+{
+  struct GlobalAnimControlInfo *ctrl = &global_anim_ctrl[part->mode_nr];
+
+  int gic_anim_nr = part->old_anim_nr + 1;	// X as in "anim_X"
+  int gic_part_nr = part->old_nr + 1;		// Y as in "part_Y"
+  int mask = event_value | (gic_anim_nr << ANIM_EVENT_ANIM_BIT);
+
+  if (!part->is_base)
+    mask |= gic_part_nr << ANIM_EVENT_PART_BIT;
+
+  int anim2_nr;
+
+  for (anim2_nr = 0; anim2_nr < ctrl->num_anims; anim2_nr++)
+  {
+    struct GlobalAnimMainControlInfo *anim2 = &ctrl->anim[anim2_nr];
+    int part2_nr;
+
+    for (part2_nr = 0; part2_nr < anim2->num_parts_all; part2_nr++)
+    {
+      struct GlobalAnimPartControlInfo *part2 = &anim2->part[part2_nr];
+
+      if (!(part2->state & ANIM_STATE_RUNNING))
+	continue;
+
+      if (isClickablePart(part2, mask))
+      {
+	part2->triggered = TRUE;
+	*click_consumed |= clickConsumed(part); 	// click was on "part"!
+
+#if DEBUG_ANIM_EVENTS
+	printf("::: => %d.%d TRIGGERED BY %s OF %d.%d\n",
+	       part2->old_anim_nr + 1, part2->old_nr + 1, info_text,
+	       part->old_anim_nr + 1, part->old_nr + 1);
+#endif
+#if 0
+	printf("::: %d.%d TRIGGER CLICKED [%d]\n", anim2_nr, part2_nr,
+	       part2->control_info.anim_event_action);
+#endif
+
+	// after executing event action, ignore any further actions
+	if (!*any_event_action && DoGlobalAnim_EventAction(part2))
+	  *any_event_action = TRUE;
+      }
+
+#if 0
+      struct GraphicInfo *c = &part2->control_info;
+
+      printf("::: - %d.%d: 0x%08x, 0x%08x [0x%08x]",
+	     anim2_nr, part2_nr, c->init_event, c->anim_event, mask);
+
+      if (isClickablePart(part2, mask))
+	printf(" <--- TRIGGERED BY %d.%d",
+	       anim_nr, part_nr);
+
+      printf("\n");
+#endif
+    }
+  }
+}
+
+static void HandleGlobalAnimDelay(struct GlobalAnimPartControlInfo *part,
+				  int delay_type, char *info_text)
+{
+#if DEBUG_ANIM_DELAY
+  printf("::: %d.%d %s\n", part->old_anim_nr + 1, part->old_nr + 1, info_text);
+#endif
+
+  DoGlobalAnim_DelayAction(part, delay_type);
+}
+
+static void HandleGlobalAnimEvent(struct GlobalAnimPartControlInfo *part,
+				  int event_value, char *info_text)
+{
+#if DEBUG_ANIM_EVENTS
+  printf("::: %d.%d %s\n", part->old_anim_nr + 1, part->old_nr + 1, info_text);
+#endif
+
+  boolean click_consumed = FALSE;
+  boolean any_event_action = FALSE;
+
+  // check if this event is defined to trigger other animations
+  InitGlobalAnim_Triggered(part, &click_consumed, &any_event_action,
+			   event_value, info_text);
+}
+
 static int HandleGlobalAnim_Part(struct GlobalAnimPartControlInfo *part,
 				 int state)
 {
+  if (handle_click && !part->clicked)
+    return state;
+
   struct GlobalAnimControlInfo *ctrl = &global_anim_ctrl[part->mode_nr];
   struct GlobalAnimMainControlInfo *anim = &ctrl->anim[part->anim_nr];
   struct GraphicInfo *g = &part->graphic_info;
@@ -1062,12 +1275,18 @@ static int HandleGlobalAnim_Part(struct GlobalAnimPartControlInfo *part,
     part->anim_delay_counter =
       (c->anim_delay_fixed + GetSimpleRandom(c->anim_delay_random));
 
-    part->init_event_state = c->init_event;
-    part->anim_event_state = c->anim_event;
+    part->post_delay_counter = 0;
+
+    part->init_event_state = (c->init_event != ANIM_EVENT_UNDEFINED);
+    part->anim_event_state = (c->anim_event != ANIM_EVENT_UNDEFINED);
 
     part->initial_anim_sync_frame =
       (g->anim_global_sync ? 0 : anim_sync_frame + part->init_delay_counter);
 
+    // do not re-initialize random animation frame after fade-in
+    if (part->anim_random_frame == -1)
+      part->anim_random_frame = GetSimpleRandom(g->anim_frames);
+
     if (c->direction & MV_HORIZONTAL)
     {
       int pos_bottom = part->viewport_height - g->height;
@@ -1131,10 +1350,13 @@ static int HandleGlobalAnim_Part(struct GlobalAnimPartControlInfo *part,
       part->step_yoffset = 0;
     }
 
-    if (c->x != ARG_UNDEFINED_VALUE)
-      part->x = c->x;
-    if (c->y != ARG_UNDEFINED_VALUE)
-      part->y = c->y;
+    if (part->control_info.class != get_hash_from_key("pointer"))
+    {
+      if (c->x != ARG_UNDEFINED_VALUE)
+	part->x = c->x;
+      if (c->y != ARG_UNDEFINED_VALUE)
+	part->y = c->y;
+    }
 
     if (c->position == POS_LAST &&
 	anim->last_x > -g->width  && anim->last_x < part->viewport_width &&
@@ -1150,27 +1372,36 @@ static int HandleGlobalAnim_Part(struct GlobalAnimPartControlInfo *part,
       part->step_yoffset = c->step_yoffset;
 
     if (part->init_delay_counter == 0 &&
-	part->init_event_state == ANIM_EVENT_NONE)
+	!part->init_event_state)
+    {
       PlayGlobalAnimSoundAndMusic(part);
+
+      HandleGlobalAnimDelay(part, ANIM_DELAY_INIT,  "START [INIT_DELAY]");
+      HandleGlobalAnimEvent(part, ANIM_EVENT_START, "START [ANIM]");
+    }
+    else
+    {
+      HandleGlobalAnimEvent(part, ANIM_EVENT_INIT, "START [INIT_DELAY/EVENT]");
+    }
   }
 
   if (part->clicked &&
-      part->init_event_state != ANIM_EVENT_NONE)
+      part->init_event_state)
   {
     if (part->initial_anim_sync_frame > 0)
       part->initial_anim_sync_frame -= part->init_delay_counter - 1;
 
     part->init_delay_counter = 1;
-    part->init_event_state = ANIM_EVENT_NONE;
+    part->init_event_state = FALSE;
 
     part->clicked = FALSE;
   }
 
   if (part->clicked &&
-      part->anim_event_state != ANIM_EVENT_NONE)
+      part->anim_event_state)
   {
     part->anim_delay_counter = 1;
-    part->anim_event_state = ANIM_EVENT_NONE;
+    part->anim_event_state = FALSE;
 
     part->clicked = FALSE;
   }
@@ -1181,15 +1412,18 @@ static int HandleGlobalAnim_Part(struct GlobalAnimPartControlInfo *part,
 
     if (part->init_delay_counter == 0)
     {
-      part->init_event_state = ANIM_EVENT_NONE;
+      part->init_event_state = FALSE;
 
       PlayGlobalAnimSoundAndMusic(part);
+
+      HandleGlobalAnimDelay(part, ANIM_DELAY_INIT,  "START [INIT_DELAY]");
+      HandleGlobalAnimEvent(part, ANIM_EVENT_START, "START [ANIM]");
     }
 
     return ANIM_STATE_WAITING;
   }
 
-  if (part->init_event_state != ANIM_EVENT_NONE)
+  if (part->init_event_state)
     return ANIM_STATE_WAITING;
 
   // animation part is now running/visible and therefore clickable
@@ -1202,7 +1436,7 @@ static int HandleGlobalAnim_Part(struct GlobalAnimPartControlInfo *part,
       (part->y >=  part->viewport_height && part->step_yoffset >= 0))
   {
     // do not wait for "anim" events for off-screen animations
-    part->anim_event_state = ANIM_EVENT_NONE;
+    part->anim_event_state = FALSE;
 
     // do not stop animation before "anim" or "post" counter are finished
     if (part->anim_delay_counter == 0 &&
@@ -1210,6 +1444,8 @@ static int HandleGlobalAnim_Part(struct GlobalAnimPartControlInfo *part,
     {
       StopGlobalAnimSoundAndMusic(part);
 
+      HandleGlobalAnimEvent(part, ANIM_EVENT_END, "END [ANIM/OFF-SCREEN]");
+
       part->post_delay_counter =
 	(c->post_delay_fixed + GetSimpleRandom(c->post_delay_random));
 
@@ -1227,10 +1463,13 @@ static int HandleGlobalAnim_Part(struct GlobalAnimPartControlInfo *part,
 
     if (part->anim_delay_counter == 0)
     {
-      part->anim_event_state = ANIM_EVENT_NONE;
+      part->anim_event_state = FALSE;
 
       StopGlobalAnimSoundAndMusic(part);
 
+      HandleGlobalAnimDelay(part, ANIM_DELAY_ANIM, "END [ANIM_DELAY]");
+      HandleGlobalAnimEvent(part, ANIM_EVENT_END,  "END [ANIM_DELAY/EVENT]");
+
       part->post_delay_counter =
 	(c->post_delay_fixed + GetSimpleRandom(c->post_delay_random));
 
@@ -1247,7 +1486,12 @@ static int HandleGlobalAnim_Part(struct GlobalAnimPartControlInfo *part,
     part->post_delay_counter--;
 
     if (part->post_delay_counter == 0)
+    {
+      HandleGlobalAnimDelay(part, ANIM_DELAY_POST, "END [POST_DELAY]");
+      HandleGlobalAnimEvent(part, ANIM_EVENT_POST, "END [POST_DELAY]");
+
       return ANIM_STATE_RESTART;
+    }
 
     return ANIM_STATE_WAITING;
   }
@@ -1475,22 +1719,37 @@ static void DoAnimationExt(void)
 #endif
 }
 
+static void DoGlobalAnim_DelayAction(struct GlobalAnimPartControlInfo *part,
+				     int delay_type)
+{
+  int delay_action =
+    (delay_type == ANIM_DELAY_INIT ? part->control_info.init_delay_action :
+     delay_type == ANIM_DELAY_ANIM ? part->control_info.anim_delay_action :
+     delay_type == ANIM_DELAY_POST ? part->control_info.post_delay_action :
+     ANIM_DELAY_ACTION_NONE);
+
+  if (delay_action == ANIM_DELAY_ACTION_NONE)
+    return;
+
+  PushUserEvent(USEREVENT_ANIM_DELAY_ACTION, delay_action, 0);
+}
+
 static boolean DoGlobalAnim_EventAction(struct GlobalAnimPartControlInfo *part)
 {
-  int anim_event_action = part->control_info.anim_event_action;
+  int event_action = (part->init_event_state ?
+		      part->control_info.init_event_action :
+		      part->control_info.anim_event_action);
 
-  if (anim_event_action == -1)
+  if (event_action == ANIM_EVENT_ACTION_NONE)
     return FALSE;
 
-  boolean action_executed = (DoGadgetAction(anim_event_action) ||
-			     DoScreenAction(anim_event_action) ||
-			     DoKeysymAction(anim_event_action));
+  PushUserEvent(USEREVENT_ANIM_EVENT_ACTION, event_action, 0);
 
   // check if further actions are allowed to be executed
   if (part->control_info.style & STYLE_MULTIPLE_ACTIONS)
     return FALSE;
 
-  return action_executed;
+  return TRUE;
 }
 
 static void InitGlobalAnim_Clickable(void)
@@ -1511,18 +1770,28 @@ static void InitGlobalAnim_Clickable(void)
       {
 	struct GlobalAnimPartControlInfo *part = &anim->part[part_nr];
 
+	if (part->triggered)
+	  part->clicked = TRUE;
+
+	part->triggered = FALSE;
 	part->clickable = FALSE;
       }
     }
   }
 }
 
-static boolean InitGlobalAnim_Clicked(int mx, int my, boolean clicked)
+#define ANIM_CLICKED_RESET	0
+#define ANIM_CLICKED_PRESSED	1
+#define ANIM_CLICKED_RELEASED	2
+
+static boolean InitGlobalAnim_Clicked(int mx, int my, int clicked_event)
 {
+  boolean click_consumed = FALSE;
   boolean anything_clicked = FALSE;
   boolean any_part_clicked = FALSE;
   boolean any_event_action = FALSE;
   int mode_nr;
+  int i;
 
   // check game modes in reverse draw order (to stop when clicked)
   for (mode_nr = NUM_GAME_MODES - 1; mode_nr >= 0; mode_nr--)
@@ -1541,7 +1810,7 @@ static boolean InitGlobalAnim_Clicked(int mx, int my, boolean clicked)
       {
 	struct GlobalAnimPartControlInfo *part = &anim->part[part_nr];
 
-	if (!clicked)
+	if (clicked_event == ANIM_CLICKED_RESET)
 	{
 	  part->clicked = FALSE;
 
@@ -1551,21 +1820,41 @@ static boolean InitGlobalAnim_Clicked(int mx, int my, boolean clicked)
 	if (!part->clickable)
 	  continue;
 
-	if (part->state != ANIM_STATE_RUNNING)
+	if (!(part->state & ANIM_STATE_RUNNING))
 	  continue;
 
 	// always handle "any" click events (clicking anywhere on screen) ...
-	if (isClickablePart(part, ANIM_EVENT_ANY))
+	if (clicked_event == ANIM_CLICKED_PRESSED &&
+	    isClickablePart(part, ANIM_EVENT_ANY))
 	{
-	  part->clicked = TRUE;
-	  anything_clicked = clickConsumed(part);
+#if DEBUG_ANIM_EVENTS
+	  printf("::: => %d.%d TRIGGERED BY ANY\n",
+		 part->old_anim_nr + 1, part->old_nr + 1);
+#endif
+
+	  anything_clicked = part->clicked = TRUE;
+	  click_consumed |= clickConsumed(part);
+	}
+
+	// always handle "unclick:any" events (releasing anywhere on screen) ...
+	if (clicked_event == ANIM_CLICKED_RELEASED &&
+	    isClickablePart(part, ANIM_EVENT_UNCLICK_ANY))
+	{
+#if DEBUG_ANIM_EVENTS
+	  printf("::: => %d.%d TRIGGERED BY UNCLICK:ANY\n",
+		 part->old_anim_nr + 1, part->old_nr + 1);
+#endif
+
+	  anything_clicked = part->clicked = TRUE;
+	  click_consumed |= clickConsumed(part);
 	}
 
 	// ... but only handle the first (topmost) clickable animation
 	if (any_part_clicked)
 	  continue;
 
-	if (isClickedPart(part, mx, my, clicked))
+	if (clicked_event == ANIM_CLICKED_PRESSED &&
+	    isClickedPart(part, mx, my, TRUE))
 	{
 #if 0
 	  printf("::: %d.%d CLICKED [%d]\n", anim_nr, part_nr,
@@ -1577,71 +1866,44 @@ static boolean InitGlobalAnim_Clicked(int mx, int my, boolean clicked)
 	    any_event_action = TRUE;
 
 	  // determine if mouse clicks should be blocked from other animations
-	  any_part_clicked = clickConsumed(part);
+	  any_part_clicked |= clickConsumed(part);
 
 	  if (isClickablePart(part, ANIM_EVENT_SELF))
 	  {
-	    part->clicked = TRUE;
-	    anything_clicked = clickConsumed(part);
+#if DEBUG_ANIM_EVENTS
+	    printf("::: => %d.%d TRIGGERED BY SELF\n",
+		   part->old_anim_nr + 1, part->old_nr + 1);
+#endif
+
+	    anything_clicked = part->clicked = TRUE;
+	    click_consumed |= clickConsumed(part);
 	  }
 
+	  // determine if mouse clicks should be blocked by this animation
+	  click_consumed |= clickBlocked(part);
+
 	  // check if this click is defined to trigger other animations
-	  int gic_anim_nr = part->old_anim_nr + 1;	// X as in "anim_X"
-	  int gic_part_nr = part->old_nr + 1;		// Y as in "part_Y"
-	  int mask = gic_anim_nr << ANIM_EVENT_ANIM_BIT;
-
-	  if (!part->is_base)
-	    mask |= gic_part_nr << ANIM_EVENT_PART_BIT;
-
-	  int anim2_nr;
-
-	  for (anim2_nr = 0; anim2_nr < ctrl->num_anims; anim2_nr++)
-	  {
-	    struct GlobalAnimMainControlInfo *anim2 = &ctrl->anim[anim2_nr];
-	    int part2_nr;
-
-	    for (part2_nr = 0; part2_nr < anim2->num_parts_all; part2_nr++)
-	    {
-	      struct GlobalAnimPartControlInfo *part2 = &anim2->part[part2_nr];
-
-	      if (part2->state != ANIM_STATE_RUNNING)
-		continue;
-
-	      if (isClickablePart(part2, mask))
-	      {
-		part2->clicked = TRUE;
-		anything_clicked = clickConsumed(part);	// click was on "part"!
-
-#if 0
-		printf("::: %d.%d TRIGGER CLICKED [%d]\n", anim2_nr, part2_nr,
-		       part2->control_info.anim_event_action);
-#endif
-
-		// after executing event action, ignore any further actions
-		if (!any_event_action && DoGlobalAnim_EventAction(part2))
-		  any_event_action = TRUE;
-	      }
-
-#if 0
-	      struct GraphicInfo *c = &part2->control_info;
-
-	      printf("::: - %d.%d: 0x%08x, 0x%08x [0x%08x]",
-		     anim2_nr, part2_nr, c->init_event, c->anim_event, mask);
-
-	      if (isClickablePart(part2, mask))
-		printf(" <--- TRIGGERED BY %d.%d",
-		       anim_nr, part_nr);
-
-	      printf("\n");
-#endif
-	    }
-	  }
+	  InitGlobalAnim_Triggered(part, &click_consumed, &any_event_action,
+				   ANIM_EVENT_CLICK, "CLICK");
 	}
       }
     }
   }
 
-  return (anything_clicked || any_event_action);
+  if (anything_clicked)
+  {
+    handle_click = TRUE;
+
+    for (i = 0; i < NUM_GAME_MODES; i++)
+      HandleGlobalAnim(ANIM_CONTINUE, i);
+
+    handle_click = FALSE;
+
+    // prevent ignoring release event if processed within same game frame
+    StopProcessingEvents();
+  }
+
+  return (click_consumed || any_event_action);
 }
 
 static void ResetGlobalAnim_Clickable(void)
@@ -1651,10 +1913,10 @@ static void ResetGlobalAnim_Clickable(void)
 
 static void ResetGlobalAnim_Clicked(void)
 {
-  InitGlobalAnim_Clicked(-1, -1, FALSE);
+  InitGlobalAnim_Clicked(-1, -1, ANIM_CLICKED_RESET);
 }
 
-boolean HandleGlobalAnimClicks(int mx, int my, int button)
+boolean HandleGlobalAnimClicks(int mx, int my, int button, boolean force_click)
 {
   static boolean click_consumed = FALSE;
   static int last_button = 0;
@@ -1662,19 +1924,25 @@ boolean HandleGlobalAnimClicks(int mx, int my, int button)
   boolean release_event;
   boolean click_consumed_current = click_consumed;
 
-  /* check if button state has changed since last invocation */
+  if (button != 0 && force_click)
+    last_button = 0;
+
+  // check if button state has changed since last invocation
   press_event   = (button != 0 && last_button == 0);
   release_event = (button == 0 && last_button != 0);
   last_button = button;
 
   if (press_event)
   {
-    click_consumed = InitGlobalAnim_Clicked(mx, my, TRUE);
+    click_consumed = InitGlobalAnim_Clicked(mx, my, ANIM_CLICKED_PRESSED);
     click_consumed_current = click_consumed;
   }
 
   if (release_event)
+  {
+    InitGlobalAnim_Clicked(mx, my, ANIM_CLICKED_RELEASED);
     click_consumed = FALSE;
+  }
 
   return click_consumed_current;
 }
