@@ -21,29 +21,28 @@
 #include "game.h"
 
 
-/* ========================================================================= */
-/* functions and definitions exported from main program to game_em           */
-/* ========================================================================= */
+// ============================================================================
+// functions and definitions exported from main program to game_em
+// ============================================================================
 
-extern void SetBitmaps_EM(Bitmap **);
-extern void UpdateEngineValues(int, int, int, int);
+void UpdateEngineValues(int, int, int, int);
 
-extern boolean getTeamMode_EM(void);
-extern int getGameFrameDelay_EM(int);
+boolean swapTiles_EM(boolean);
+boolean getTeamMode_EM(void);
+boolean isActivePlayer_EM(int);
 
-extern void PlayLevelSound_EM(int, int, int, int);
-extern void InitGraphicInfo_EM(void);
-extern void CheckSingleStepMode_EM(byte action[], int,
-				   boolean, boolean, boolean);
+void PlayLevelSound_EM(int, int, int, int);
+void InitGraphicInfo_EM(void);
+void CheckSingleStepMode_EM(byte action[], int, boolean, boolean, boolean);
 
 void SetGfxAnimation_EM(struct GraphicInfo_EM *, int, int, int, int);
 void getGraphicSourceObjectExt_EM(struct GraphicInfo_EM *, int, int, int, int);
 void getGraphicSourcePlayerExt_EM(struct GraphicInfo_EM *, int, int, int);
 
 
-/* ========================================================================= */
-/* functions and definitions exported from main program to game_sp           */
-/* ========================================================================= */
+// ============================================================================
+// functions and definitions exported from main program to game_sp
+// ============================================================================
 
 void CheckSingleStepMode_SP(boolean, boolean);
 
@@ -52,9 +51,9 @@ int getGraphicInfo_Delay(int);
 boolean isNextAnimationFrame_SP(int, int);
 
 
-/* ========================================================================= */
-/* functions and definitions exported from main program to game_mm           */
-/* ========================================================================= */
+// ============================================================================
+// functions and definitions exported from main program to game_mm
+// ============================================================================
 
 void SetDrawtoField(int);
 
@@ -67,4 +66,4 @@ void getMiniGraphicSource(int, Bitmap **, int *, int *);
 void getSizedGraphicSource(int, int, int, Bitmap **, int *, int *);
 
 
-#endif	/* ENGINES_H */
+#endif	// ENGINES_H
