@@ -1,15 +1,13 @@
-/***********************************************************
-* Mirror Magic -- McDuffin's Revenge                       *
-*----------------------------------------------------------*
-* (c) 1994-2001 Artsoft Entertainment                      *
-*               Holger Schemel                             *
-*               Detmolder Strasse 189                      *
-*               33604 Bielefeld                            *
-*               Germany                                    *
-*               e-mail: info@artsoft.org                   *
-*----------------------------------------------------------*
-* tools.c                                                  *
-***********************************************************/
+// ============================================================================
+// Mirror Magic -- McDuffin's Revenge
+// ----------------------------------------------------------------------------
+// (c) 1994-2017 by Artsoft Entertainment
+//     		    Holger Schemel
+//		    info@artsoft.org
+//		    http://www.artsoft.org/
+// ----------------------------------------------------------------------------
+// mm_tools.c
+// ============================================================================
 
 #include "main_mm.h"
 
@@ -159,35 +157,35 @@ void DrawGraphicShifted_MM(int x,int y, int dx,int dy, int graphic,
     return;
   }
 
-  if (dx || dy)			/* Verschiebung der Grafik? */
+  if (dx || dy)			// Verschiebung der Grafik?
   {
-    if (x < BX1)		/* Element kommt von links ins Bild */
+    if (x < BX1)		// Element kommt von links ins Bild
     {
       x = BX1;
       width = dx;
       cx = TILEX - dx;
       dx = 0;
     }
-    else if (x > BX2)		/* Element kommt von rechts ins Bild */
+    else if (x > BX2)		// Element kommt von rechts ins Bild
     {
       x = BX2;
       width = -dx;
       dx = TILEX + dx;
     }
-    else if (x==BX1 && dx < 0)	/* Element verläßt links das Bild */
+    else if (x==BX1 && dx < 0)	// Element verläßt links das Bild
     {
       width += dx;
       cx = -dx;
       dx = 0;
     }
-    else if (x==BX2 && dx > 0)	/* Element verläßt rechts das Bild */
+    else if (x==BX2 && dx > 0)	// Element verläßt rechts das Bild
       width -= dx;
-    else if (dx)		/* allg. Bewegung in x-Richtung */
+    else if (dx)		// allg. Bewegung in x-Richtung
       MarkTileDirty(x + SIGN(dx), y);
 
-    if (y < BY1)		/* Element kommt von oben ins Bild */
+    if (y < BY1)		// Element kommt von oben ins Bild
     {
-      if (cut_mode==CUT_BELOW)	/* Element oberhalb des Bildes */
+      if (cut_mode==CUT_BELOW)	// Element oberhalb des Bildes
 	return;
 
       y = BY1;
@@ -195,13 +193,13 @@ void DrawGraphicShifted_MM(int x,int y, int dx,int dy, int graphic,
       cy = TILEY - dy;
       dy = 0;
     }
-    else if (y > BY2)		/* Element kommt von unten ins Bild */
+    else if (y > BY2)		// Element kommt von unten ins Bild
     {
       y = BY2;
       height = -dy;
       dy = TILEY + dy;
     }
-    else if (y==BY1 && dy < 0)	/* Element verläßt oben das Bild */
+    else if (y==BY1 && dy < 0)	// Element verläßt oben das Bild
     {
       height += dy;
       cy = -dy;
@@ -209,19 +207,19 @@ void DrawGraphicShifted_MM(int x,int y, int dx,int dy, int graphic,
     }
     else if (dy > 0 && cut_mode == CUT_ABOVE)
     {
-      if (y == BY2)		/* Element unterhalb des Bildes */
+      if (y == BY2)		// Element unterhalb des Bildes
 	return;
 
       height = dy;
       cy = TILEY - dy;
       dy = TILEY;
       MarkTileDirty(x, y + 1);
-    }				/* Element verläßt unten das Bild */
+    }				// Element verläßt unten das Bild
     else if (dy > 0 && (y == BY2 || cut_mode == CUT_BELOW))
     {
       height -= dy;
     }
-    else if (dy)		/* allg. Bewegung in y-Richtung */
+    else if (dy)		// allg. Bewegung in y-Richtung
     {
       MarkTileDirty(x, y + SIGN(dy));
     }
@@ -615,8 +613,8 @@ void DrawMiniLevel_MM(int size_x, int size_y, int scroll_x, int scroll_y)
 {
   int x, y;
 
-  for(x = 0; x < size_x; x++)
-    for(y = 0; y < size_y; y++)
+  for (x = 0; x < size_x; x++)
+    for (y = 0; y < size_y; y++)
       DrawMiniElementOrWall_MM(x, y, scroll_x, scroll_y);
 
   redraw_mask |= REDRAW_FIELD;
