@@ -21,15 +21,16 @@
 #include "joystick.h"
 #include "misc.h"
 
-#define ENABLE_UNUSED_CODE	0	/* currently unused functions */
+#define ENABLE_UNUSED_CODE	0	// currently unused functions
 
 
-/* ========================================================================= */
-/* exported variables                                                        */
-/* ========================================================================= */
+// ============================================================================
+// exported variables
+// ============================================================================
 
 struct ProgramInfo	program;
 struct NetworkInfo	network;
+struct RuntimeInfo	runtime;
 struct OptionInfo	options;
 struct VideoSystemInfo	video;
 struct AudioSystemInfo	audio;
@@ -55,18 +56,17 @@ DrawBuffer	       *drawto = NULL;
 int			button_status = MB_NOT_PRESSED;
 boolean			motion_status = FALSE;
 int			wheel_steps = DEFAULT_WHEEL_STEPS;
-#if defined(TARGET_SDL2)
 boolean			keyrepeat_status = TRUE;
-#endif
+boolean			textinput_status = FALSE;
 
 int			redraw_mask = REDRAW_NONE;
 
 int			FrameCounter = 0;
 
 
-/* ========================================================================= */
-/* init/close functions                                                      */
-/* ========================================================================= */
+// ============================================================================
+// init/close functions
+// ============================================================================
 
 void InitProgramInfo(char *argv0, char *config_filename, char *userdata_subdir,
 		     char *program_title, char *icon_title,
@@ -116,6 +116,15 @@ void InitNetworkInfo(boolean enabled, boolean connected, boolean serveronly,
   network.server_port = server_port;
 }
 
+void InitRuntimeInfo()
+{
+#if defined(HAS_TOUCH_DEVICE)
+  runtime.uses_touch_device = TRUE;
+#else
+  runtime.uses_touch_device = FALSE;
+#endif
+}
+
 void InitScoresInfo(void)
 {
   char *global_scores_dir = getPath2(getCommonDataDir(), SCORES_DIRECTORY);
@@ -164,11 +173,11 @@ void InitExitFunction(void (*exit_function)(int))
 {
   program.exit_function = exit_function;
 
-  /* set signal handlers to custom exit function */
+  // set signal handlers to custom exit function
   // signal(SIGINT, exit_function);
   signal(SIGTERM, exit_function);
 
-  /* set exit function to automatically cleanup SDL stuff after exit() */
+  // set exit function to automatically cleanup SDL stuff after exit()
   atexit(SDL_Quit);
 }
 
@@ -179,11 +188,7 @@ void InitPlatformDependentStuff(void)
 
   OpenLogFiles();
 
-#if defined(TARGET_SDL2)
-  int sdl_init_flags = SDL_INIT_EVENTS      | SDL_INIT_NOPARACHUTE;
-#else
-  int sdl_init_flags = SDL_INIT_EVENTTHREAD | SDL_INIT_NOPARACHUTE;
-#endif
+  int sdl_init_flags = SDL_INIT_EVENTS | SDL_INIT_NOPARACHUTE;
 
   if (SDL_Init(sdl_init_flags) < 0)
     Error(ERR_EXIT, "SDL_Init() failed: %s", SDL_GetError());
@@ -212,8 +217,8 @@ void InitGfxFieldInfo(int sx, int sy, int sxsize, int sysize,
 
   gfx.field_save_buffer = field_save_buffer;
 
-  SetDrawDeactivationMask(REDRAW_NONE);		/* do not deactivate drawing */
-  SetDrawBackgroundMask(REDRAW_NONE);		/* deactivate masked drawing */
+  SetDrawDeactivationMask(REDRAW_NONE);		// do not deactivate drawing
+  SetDrawBackgroundMask(REDRAW_NONE);		// deactivate masked drawing
 }
 
 void InitGfxTileSizeInfo(int game_tile_size, int standard_tile_size)
@@ -252,9 +257,7 @@ void InitGfxWindowInfo(int win_xsize, int win_ysize)
   {
     ReCreateBitmap(&gfx.background_bitmap, win_xsize, win_ysize);
 
-#if defined(TARGET_SDL2)
     ReCreateBitmap(&gfx.final_screen_bitmap, win_xsize, win_ysize);
-#endif
 
     ReCreateBitmap(&gfx.fade_bitmap_backup, win_xsize, win_ysize);
     ReCreateBitmap(&gfx.fade_bitmap_source, win_xsize, win_ysize);
@@ -272,8 +275,8 @@ void InitGfxWindowInfo(int win_xsize, int win_ysize)
 
 void InitGfxScrollbufferInfo(int scrollbuffer_width, int scrollbuffer_height)
 {
-  /* currently only used by MSDOS code to alloc VRAM buffer, if available */
-  /* 2009-03-24: also (temporarily?) used for overlapping blit workaround */
+  // currently only used by MSDOS code to alloc VRAM buffer, if available
+  // 2009-03-24: also (temporarily?) used for overlapping blit workaround
   gfx.scrollbuffer_width = scrollbuffer_width;
   gfx.scrollbuffer_height = scrollbuffer_height;
 }
@@ -319,6 +322,12 @@ void InitGfxCustomArtworkInfo(void)
 void InitGfxOtherSettings(void)
 {
   gfx.cursor_mode = CURSOR_DEFAULT;
+  gfx.cursor_mode_override = CURSOR_UNDEFINED;
+  gfx.cursor_mode_final = gfx.cursor_mode;
+
+  // prevent initially displaying custom mouse cursor in upper left corner
+  gfx.mouse_x = POS_OFFSCREEN;
+  gfx.mouse_y = POS_OFFSCREEN;
 }
 
 void InitTileCursorInfo(void)
@@ -425,6 +434,11 @@ void SetOverlayShowGrid(boolean show_grid)
     SetOverlayEnabled(TRUE);
 }
 
+boolean GetOverlayEnabled(void)
+{
+  return overlay.enabled;
+}
+
 boolean GetOverlayActive(void)
 {
   return overlay.active;
@@ -452,7 +466,7 @@ static void SetBackgroundBitmap(Bitmap *background_bitmap_tile, int mask)
   else
     gfx.background_bitmap_mask &= ~mask;
 
-  if (background_bitmap_tile == NULL)	/* empty background requested */
+  if (background_bitmap_tile == NULL)	// empty background requested
     return;
 
   if (mask == REDRAW_ALL)
@@ -468,40 +482,40 @@ static void SetBackgroundBitmap(Bitmap *background_bitmap_tile, int mask)
 
 void SetWindowBackgroundBitmap(Bitmap *background_bitmap_tile)
 {
-  /* remove every mask before setting mask for window */
-  /* (!!! TO BE FIXED: The whole REDRAW_* system really sucks! !!!) */
-  SetBackgroundBitmap(NULL, 0xffff);		/* !!! FIX THIS !!! */
+  // remove every mask before setting mask for window
+  // (!!! TO BE FIXED: The whole REDRAW_* system really sucks! !!!)
+  SetBackgroundBitmap(NULL, 0xffff);		// !!! FIX THIS !!!
   SetBackgroundBitmap(background_bitmap_tile, REDRAW_ALL);
 }
 
 void SetMainBackgroundBitmap(Bitmap *background_bitmap_tile)
 {
-  /* remove window area mask before setting mask for main area */
-  /* (!!! TO BE FIXED: The whole REDRAW_* system really sucks! !!!) */
-  SetBackgroundBitmap(NULL, REDRAW_ALL);	/* !!! FIX THIS !!! */
+  // remove window area mask before setting mask for main area
+  // (!!! TO BE FIXED: The whole REDRAW_* system really sucks! !!!)
+  SetBackgroundBitmap(NULL, REDRAW_ALL);	// !!! FIX THIS !!!
   SetBackgroundBitmap(background_bitmap_tile, REDRAW_FIELD);
 }
 
 void SetDoorBackgroundBitmap(Bitmap *background_bitmap_tile)
 {
-  /* remove window area mask before setting mask for door area */
-  /* (!!! TO BE FIXED: The whole REDRAW_* system really sucks! !!!) */
-  SetBackgroundBitmap(NULL, REDRAW_ALL);	/* !!! FIX THIS !!! */
+  // remove window area mask before setting mask for door area
+  // (!!! TO BE FIXED: The whole REDRAW_* system really sucks! !!!)
+  SetBackgroundBitmap(NULL, REDRAW_ALL);	// !!! FIX THIS !!!
   SetBackgroundBitmap(background_bitmap_tile, REDRAW_DOOR_1);
 }
 
 
-/* ========================================================================= */
-/* video functions                                                           */
-/* ========================================================================= */
+// ============================================================================
+// video functions
+// ============================================================================
 
-inline static int GetRealDepth(int depth)
+static int GetRealDepth(int depth)
 {
   return (depth == DEFAULT_DEPTH ? video.default_depth : depth);
 }
 
-inline static void sysFillRectangle(Bitmap *bitmap, int x, int y,
-				    int width, int height, Pixel color)
+static void sysFillRectangle(Bitmap *bitmap, int x, int y,
+			     int width, int height, Pixel color)
 {
   SDLFillRectangle(bitmap, x, y, width, height, color);
 
@@ -509,9 +523,9 @@ inline static void sysFillRectangle(Bitmap *bitmap, int x, int y,
     SetRedrawMaskFromArea(x, y, width, height);
 }
 
-inline static void sysCopyArea(Bitmap *src_bitmap, Bitmap *dst_bitmap,
-			       int src_x, int src_y, int width, int height,
-			       int dst_x, int dst_y, int mask_mode)
+static void sysCopyArea(Bitmap *src_bitmap, Bitmap *dst_bitmap,
+			int src_x, int src_y, int width, int height,
+			int dst_x, int dst_y, int mask_mode)
 {
   SDLCopyArea(src_bitmap, dst_bitmap, src_x, src_y, width, height,
 	      dst_x, dst_y, mask_mode);
@@ -536,9 +550,7 @@ void InitVideoDisplay(void)
     return;
 
   SDLInitVideoDisplay();
-#if defined(TARGET_SDL2)
   SDLSetDisplaySize();
-#endif
 }
 
 void CloseVideoDisplay(void)
@@ -564,6 +576,7 @@ void InitVideoBuffer(int width, int height, int depth, boolean fullscreen)
 
   video.window_scaling_available = WINDOW_SCALING_STATUS;
 
+  video.frame_counter = 0;
   video.frame_delay = 0;
   video.frame_delay_value = GAME_FRAME_DELAY;
 
@@ -580,7 +593,7 @@ void InitVideoBuffer(int width, int height, int depth, boolean fullscreen)
   drawto = backbuffer;
 }
 
-inline static void FreeBitmapPointers(Bitmap *bitmap)
+static void FreeBitmapPointers(Bitmap *bitmap)
 {
   if (bitmap == NULL)
     return;
@@ -591,8 +604,8 @@ inline static void FreeBitmapPointers(Bitmap *bitmap)
   bitmap->source_filename = NULL;
 }
 
-inline static void TransferBitmapPointers(Bitmap *src_bitmap,
-					  Bitmap *dst_bitmap)
+static void TransferBitmapPointers(Bitmap *src_bitmap,
+				   Bitmap *dst_bitmap)
 {
   if (src_bitmap == NULL || dst_bitmap == NULL)
     return;
@@ -620,8 +633,8 @@ Bitmap *CreateBitmapStruct(void)
 Bitmap *CreateBitmap(int width, int height, int depth)
 {
   Bitmap *new_bitmap = CreateBitmapStruct();
-  int real_width  = MAX(1, width);	/* prevent zero bitmap width */
-  int real_height = MAX(1, height);	/* prevent zero bitmap height */
+  int real_width  = MAX(1, width);	// prevent zero bitmap width
+  int real_height = MAX(1, height);	// prevent zero bitmap height
   int real_depth  = GetRealDepth(depth);
 
   SDLCreateBitmapContent(new_bitmap, real_width, real_height, real_depth);
@@ -636,12 +649,12 @@ void ReCreateBitmap(Bitmap **bitmap, int width, int height)
 {
   if (*bitmap != NULL)
   {
-    /* if new bitmap size fits into old one, no need to re-create it */
+    // if new bitmap size fits into old one, no need to re-create it
     if (width  <= (*bitmap)->width &&
         height <= (*bitmap)->height)
       return;
 
-    /* else adjust size so that old and new bitmap size fit into it */
+    // else adjust size so that old and new bitmap size fit into it
     width  = MAX(width,  (*bitmap)->width);
     height = MAX(height, (*bitmap)->height);
   }
@@ -687,8 +700,8 @@ void SetRedrawMaskFromArea(int x, int y, int width, int height)
     redraw_mask = REDRAW_ALL;
 }
 
-inline static boolean CheckDrawingArea(int x, int y, int width, int height,
-				       int draw_mask)
+static boolean CheckDrawingArea(int x, int y, int width, int height,
+				int draw_mask)
 {
   if (draw_mask == REDRAW_NONE)
     return FALSE;
@@ -738,7 +751,7 @@ static boolean InClippedRectangle(Bitmap *bitmap, int *x, int *y,
 {
   int clip_x, clip_y, clip_width, clip_height;
 
-  if (gfx.clipping_enabled && is_dest)	/* only clip destination bitmap */
+  if (gfx.clipping_enabled && is_dest)	// only clip destination bitmap
   {
     clip_x = MIN(MAX(0, gfx.clip_x), bitmap->width);
     clip_y = MIN(MAX(0, gfx.clip_y), bitmap->height);
@@ -753,7 +766,7 @@ static boolean InClippedRectangle(Bitmap *bitmap, int *x, int *y,
     clip_height = bitmap->height;
   }
 
-  /* skip if rectangle completely outside bitmap */
+  // skip if rectangle completely outside bitmap
 
   if (*x + *width  <= clip_x ||
       *y + *height <= clip_y ||
@@ -761,7 +774,7 @@ static boolean InClippedRectangle(Bitmap *bitmap, int *x, int *y,
       *y >= clip_y + clip_height)
     return FALSE;
 
-  /* clip if rectangle overlaps bitmap */
+  // clip if rectangle overlaps bitmap
 
   if (*x < clip_x)
   {
@@ -806,35 +819,34 @@ void BlitBitmap(Bitmap *src_bitmap, Bitmap *dst_bitmap,
       !InClippedRectangle(dst_bitmap, &dst_x, &dst_y, &width, &height, TRUE))
     return;
 
-  /* source x/y might need adjustment if destination x/y was clipped top/left */
+  // source x/y might need adjustment if destination x/y was clipped top/left
   src_x += dst_x - dst_x_unclipped;
   src_y += dst_y - dst_y_unclipped;
 
-#if defined(TARGET_SDL2)
-  /* !!! 2013-12-11: An "old friend" is back. Same bug in SDL2 2.0.1 !!! */
-  /* !!! 2009-03-30: Fixed by using self-compiled, patched SDL.dll !!! */
+  // !!! 2013-12-11: An "old friend" is back. Same bug in SDL2 2.0.1 !!!
+  // !!! 2009-03-30: Fixed by using self-compiled, patched SDL.dll !!!
   /* (This bug still exists in the actual (as of 2009-06-15) version 1.2.13,
      but is already fixed in SVN and should therefore finally be fixed with
      the next official SDL release, which is probably version 1.2.14.) */
-  /* !!! 2009-03-24: It seems that this problem still exists in 1.2.12 !!! */
+  // !!! 2009-03-24: It seems that this problem still exists in 1.2.12 !!!
 
   if (src_bitmap == dst_bitmap)
   {
-    /* needed when blitting directly to same bitmap -- should not be needed with
-       recent SDL libraries, but apparently does not work in 1.2.11 directly */
+    // needed when blitting directly to same bitmap -- should not be needed with
+    // recent SDL libraries, but apparently does not work in 1.2.11 directly
 
     static Bitmap *tmp_bitmap = NULL;
     static int tmp_bitmap_xsize = 0;
     static int tmp_bitmap_ysize = 0;
 
-    /* start with largest static bitmaps for initial bitmap size ... */
+    // start with largest static bitmaps for initial bitmap size ...
     if (tmp_bitmap_xsize == 0 && tmp_bitmap_ysize == 0)
     {
       tmp_bitmap_xsize = MAX(gfx.win_xsize, gfx.scrollbuffer_width);
       tmp_bitmap_ysize = MAX(gfx.win_ysize, gfx.scrollbuffer_height);
     }
 
-    /* ... and allow for later re-adjustments due to custom artwork bitmaps */
+    // ... and allow for later re-adjustments due to custom artwork bitmaps
     if (src_bitmap->width > tmp_bitmap_xsize ||
 	src_bitmap->height > tmp_bitmap_ysize)
     {
@@ -857,7 +869,6 @@ void BlitBitmap(Bitmap *src_bitmap, Bitmap *dst_bitmap,
 
     return;
   }
-#endif
 
   sysCopyArea(src_bitmap, dst_bitmap,
 	      src_x, src_y, width, height, dst_x, dst_y, BLIT_OPAQUE);
@@ -894,7 +905,7 @@ void FadeRectangle(int x, int y, int width, int height,
 		   int fade_mode, int fade_delay, int post_delay,
 		   void (*draw_border_function)(void))
 {
-  /* (use destination bitmap "backbuffer" -- "bitmap_cross" may be undefined) */
+  // (use destination bitmap "backbuffer" -- "bitmap_cross" may be undefined)
   if (!InClippedRectangle(backbuffer, &x, &y, &width, &height, TRUE))
     return;
 
@@ -945,11 +956,11 @@ void BlitBitmapOnBackground(Bitmap *src_bitmap, Bitmap *dst_bitmap,
 {
   if (DrawingOnBackground(dst_x, dst_y))
   {
-    /* draw background */
+    // draw background
     BlitBitmap(gfx.background_bitmap, dst_bitmap, dst_x, dst_y, width, height,
 	       dst_x, dst_y);
 
-    /* draw foreground */
+    // draw foreground
     BlitBitmapMasked(src_bitmap, dst_bitmap, src_x, src_y, width, height,
 		     dst_x, dst_y);
   }
@@ -1093,23 +1104,12 @@ Pixel GetPixelFromRGBcompact(Bitmap *bitmap, unsigned int color)
 
 void KeyboardAutoRepeatOn(void)
 {
-#if defined(TARGET_SDL2)
   keyrepeat_status = TRUE;
-#else
-  SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY / 2,
-		      SDL_DEFAULT_REPEAT_INTERVAL / 2);
-  SDL_EnableUNICODE(1);
-#endif
 }
 
 void KeyboardAutoRepeatOff(void)
 {
-#if defined(TARGET_SDL2)
   keyrepeat_status = FALSE;
-#else
-  SDL_EnableKeyRepeat(0, SDL_DEFAULT_REPEAT_INTERVAL);
-  SDL_EnableUNICODE(0);
-#endif
 }
 
 boolean SetVideoMode(boolean fullscreen)
@@ -1167,7 +1167,7 @@ void ReloadCustomImage(Bitmap *bitmap, char *basename)
   char *filename = getCustomImageFilename(basename);
   Bitmap *new_bitmap;
 
-  if (filename == NULL)		/* (should never happen) */
+  if (filename == NULL)		// (should never happen)
   {
     Error(ERR_WARN, "ReloadCustomImage(): cannot find file '%s'", basename);
     return;
@@ -1175,9 +1175,9 @@ void ReloadCustomImage(Bitmap *bitmap, char *basename)
 
   if (strEqual(filename, bitmap->source_filename))
   {
-    /* The old and new image are the same (have the same filename and path).
-       This usually means that this image does not exist in this graphic set
-       and a fallback to the existing image is done. */
+    // The old and new image are the same (have the same filename and path).
+    // This usually means that this image does not exist in this graphic set
+    // and a fallback to the existing image is done.
 
     return;
   }
@@ -1260,12 +1260,12 @@ static void CreateScaledBitmaps(Bitmap **bitmaps, int zoom_factor,
   old_width  = old_bitmap->width;
   old_height = old_bitmap->height;
 
-  /* calculate new image dimensions for final image size */
+  // calculate new image dimensions for final image size
   width_final  = old_width  * zoom_factor;
   height_final = old_height * zoom_factor;
 
-  /* get image with final size (this might require scaling up) */
-  /* ("final" size may result in non-standard tile size image) */
+  // get image with final size (this might require scaling up)
+  // ("final" size may result in non-standard tile size image)
   if (zoom_factor != 1)
     tmp_bitmap_final = ZoomBitmap(old_bitmap, width_final, height_final);
   else
@@ -1280,10 +1280,10 @@ static void CreateScaledBitmaps(Bitmap **bitmaps, int zoom_factor,
 
   if (create_small_bitmaps)
   {
-    /* check if we have a non-gameplay tile size image */
+    // check if we have a non-gameplay tile size image
     if (tile_size != gfx.game_tile_size)
     {
-      /* get image with gameplay tile size */
+      // get image with gameplay tile size
       width_0  = width_final  * gfx.game_tile_size / tile_size;
       height_0 = height_final * gfx.game_tile_size / tile_size;
 
@@ -1297,10 +1297,10 @@ static void CreateScaledBitmaps(Bitmap **bitmaps, int zoom_factor,
       UPDATE_BUSY_STATE();
     }
 
-    /* check if we have a non-standard tile size image */
+    // check if we have a non-standard tile size image
     if (tile_size != gfx.standard_tile_size)
     {
-      /* get image with standard tile size */
+      // get image with standard tile size
       width_1  = width_final  * gfx.standard_tile_size / tile_size;
       height_1 = height_final * gfx.standard_tile_size / tile_size;
 
@@ -1316,7 +1316,7 @@ static void CreateScaledBitmaps(Bitmap **bitmaps, int zoom_factor,
       UPDATE_BUSY_STATE();
     }
 
-    /* calculate new image dimensions for small images */
+    // calculate new image dimensions for small images
     width_2  = width_1  / 2;
     height_2 = height_1 / 2;
     width_4  = width_1  / 4;
@@ -1328,7 +1328,7 @@ static void CreateScaledBitmaps(Bitmap **bitmaps, int zoom_factor,
     width_32  = width_1  / 32;
     height_32 = height_1 / 32;
 
-    /* get image with 1/2 of normal size (for use in the level editor) */
+    // get image with 1/2 of normal size (for use in the level editor)
     if (width_2 == old_width)
       tmp_bitmap_2 = old_bitmap;
     else
@@ -1336,7 +1336,7 @@ static void CreateScaledBitmaps(Bitmap **bitmaps, int zoom_factor,
 
     UPDATE_BUSY_STATE();
 
-    /* get image with 1/4 of normal size (for use in the level editor) */
+    // get image with 1/4 of normal size (for use in the level editor)
     if (width_4 == old_width)
       tmp_bitmap_4 = old_bitmap;
     else
@@ -1344,7 +1344,7 @@ static void CreateScaledBitmaps(Bitmap **bitmaps, int zoom_factor,
 
     UPDATE_BUSY_STATE();
 
-    /* get image with 1/8 of normal size (for use on the preview screen) */
+    // get image with 1/8 of normal size (for use on the preview screen)
     if (width_8 == old_width)
       tmp_bitmap_8 = old_bitmap;
     else
@@ -1352,7 +1352,7 @@ static void CreateScaledBitmaps(Bitmap **bitmaps, int zoom_factor,
 
     UPDATE_BUSY_STATE();
 
-    /* get image with 1/16 of normal size (for use on the preview screen) */
+    // get image with 1/16 of normal size (for use on the preview screen)
     if (width_16 == old_width)
       tmp_bitmap_16 = old_bitmap;
     else
@@ -1360,7 +1360,7 @@ static void CreateScaledBitmaps(Bitmap **bitmaps, int zoom_factor,
 
     UPDATE_BUSY_STATE();
 
-    /* get image with 1/32 of normal size (for use on the preview screen) */
+    // get image with 1/32 of normal size (for use on the preview screen)
     if (width_32 == old_width)
       tmp_bitmap_32 = old_bitmap;
     else
@@ -1391,7 +1391,7 @@ static void CreateScaledBitmaps(Bitmap **bitmaps, int zoom_factor,
 
     if (free_old_bitmap)
     {
-      /* copy image filename from old to new standard sized bitmap */
+      // copy image filename from old to new standard sized bitmap
       bitmaps[IMG_BITMAP_STANDARD]->source_filename =
 	getStringCopy(old_bitmap->source_filename);
 
@@ -1430,24 +1430,24 @@ void ScaleBitmap(Bitmap **bitmaps, int zoom_factor)
 }
 
 
-/* ------------------------------------------------------------------------- */
-/* mouse pointer functions                                                   */
-/* ------------------------------------------------------------------------- */
+// ----------------------------------------------------------------------------
+// mouse pointer functions
+// ----------------------------------------------------------------------------
 
 #define USE_ONE_PIXEL_PLAYFIELD_MOUSEPOINTER		0
 
-/* XPM image definitions */
+// XPM image definitions
 static const char *cursor_image_none[] =
 {
-  /* width height num_colors chars_per_pixel */
+  // width height num_colors chars_per_pixel
   "    16    16        3            1",
 
-  /* colors */
+  // colors
   "X c #000000",
   ". c #ffffff",
   "  c None",
 
-  /* pixels */
+  // pixels
   "                ",
   "                ",
   "                ",
@@ -1465,22 +1465,22 @@ static const char *cursor_image_none[] =
   "                ",
   "                ",
 
-  /* hot spot */
+  // hot spot
   "0,0"
 };
 
 #if USE_ONE_PIXEL_PLAYFIELD_MOUSEPOINTER
 static const char *cursor_image_dot[] =
 {
-  /* width height num_colors chars_per_pixel */
+  // width height num_colors chars_per_pixel
   "    16    16        3            1",
 
-  /* colors */
+  // colors
   "X c #000000",
   ". c #ffffff",
   "  c None",
 
-  /* pixels */
+  // pixels
   " X              ",
   "X.X             ",
   " X              ",
@@ -1498,13 +1498,13 @@ static const char *cursor_image_dot[] =
   "                ",
   "                ",
 
-  /* hot spot */
+  // hot spot
   "1,1"
 };
 static const char **cursor_image_playfield = cursor_image_dot;
 #else
-/* some people complained about a "white dot" on the screen and thought it
-   was a graphical error... OK, let's just remove the whole pointer :-) */
+// some people complained about a "white dot" on the screen and thought it
+// was a graphical error... OK, let's just remove the whole pointer :-)
 static const char **cursor_image_playfield = cursor_image_none;
 #endif
 
@@ -1562,6 +1562,7 @@ void SetMouseCursor(int mode)
   static struct MouseCursorInfo *cursor_none = NULL;
   static struct MouseCursorInfo *cursor_playfield = NULL;
   struct MouseCursorInfo *cursor_new;
+  int mode_final = mode;
 
   if (cursor_none == NULL)
     cursor_none = get_cursor_from_image(cursor_image_none);
@@ -1569,23 +1570,49 @@ void SetMouseCursor(int mode)
   if (cursor_playfield == NULL)
     cursor_playfield = get_cursor_from_image(cursor_image_playfield);
 
-  cursor_new = (mode == CURSOR_DEFAULT   ? NULL :
-		mode == CURSOR_NONE      ? cursor_none :
-		mode == CURSOR_PLAYFIELD ? cursor_playfield : NULL);
+  if (gfx.cursor_mode_override != CURSOR_UNDEFINED)
+    mode_final = gfx.cursor_mode_override;
+
+  cursor_new = (mode_final == CURSOR_DEFAULT   ? NULL :
+		mode_final == CURSOR_NONE      ? cursor_none :
+		mode_final == CURSOR_PLAYFIELD ? cursor_playfield : NULL);
 
   SDLSetMouseCursor(cursor_new);
 
   gfx.cursor_mode = mode;
+  gfx.cursor_mode_final = mode_final;
+}
+
+void UpdateRawMousePosition(int mouse_x, int mouse_y)
+{
+  // mouse events do not contain logical screen size corrections yet
+  SDLCorrectRawMousePosition(&mouse_x, &mouse_y);
+
+  mouse_x -= video.screen_xoffset;
+  mouse_y -= video.screen_yoffset;
+
+  gfx.mouse_x = mouse_x;
+  gfx.mouse_y = mouse_y;
+}
+
+void UpdateMousePosition(void)
+{
+  int mouse_x, mouse_y;
+
+  SDL_PumpEvents();
+  SDL_GetMouseState(&mouse_x, &mouse_y);
+
+  UpdateRawMousePosition(mouse_x, mouse_y);
 }
 
 
-/* ========================================================================= */
-/* audio functions                                                           */
-/* ========================================================================= */
+// ============================================================================
+// audio functions
+// ============================================================================
 
 void OpenAudio(void)
 {
-  /* always start with reliable default values */
+  // always start with reliable default values
   audio.sound_available = FALSE;
   audio.music_available = FALSE;
   audio.loops_available = FALSE;
@@ -1621,9 +1648,14 @@ void SetAudioMode(boolean enabled)
 }
 
 
-/* ========================================================================= */
-/* event functions                                                           */
-/* ========================================================================= */
+// ============================================================================
+// event functions
+// ============================================================================
+
+void InitEventFilter(EventFilter filter_function)
+{
+  SDL_SetEventFilter(filter_function, NULL);
+}
 
 boolean PendingEvent(void)
 {
@@ -1637,11 +1669,12 @@ void WaitEvent(Event *event)
 
 void PeekEvent(Event *event)
 {
-#if defined(TARGET_SDL2)
   SDL_PeepEvents(event, 1, SDL_PEEKEVENT, SDL_FIRSTEVENT, SDL_LASTEVENT);
-#else
-  SDL_PeepEvents(event, 1, SDL_PEEKEVENT, SDL_ALLEVENTS);
-#endif
+}
+
+void PumpEvents(void)
+{
+  SDL_PumpEvents();
 }
 
 void CheckQuitEvent(void)
@@ -1652,37 +1685,19 @@ void CheckQuitEvent(void)
 
 Key GetEventKey(KeyEvent *event, boolean with_modifiers)
 {
-#if defined(TARGET_SDL2)
-  /* key up/down events in SDL2 do not return text characters anymore */
+  // key up/down events in SDL2 do not return text characters anymore
   return event->keysym.sym;
-#else
-
-#if ENABLE_UNUSED_CODE
-  printf("unicode == '%d', sym == '%d', mod == '0x%04x'\n",
-	 (int)event->keysym.unicode,
-	 (int)event->keysym.sym,
-	 (int)SDL_GetModState());
-#endif
-
-  if (with_modifiers &&
-      event->keysym.unicode > 0x0000 &&
-      event->keysym.unicode < 0x2000)
-    return event->keysym.unicode;
-  else
-    return event->keysym.sym;
-
-#endif
 }
 
 KeyMod HandleKeyModState(Key key, int key_status)
 {
   static KeyMod current_modifiers = KMOD_None;
 
-  if (key != KSYM_UNDEFINED)	/* new key => check for modifier key change */
+  if (key != KSYM_UNDEFINED)	// new key => check for modifier key change
   {
     KeyMod new_modifier = KMOD_None;
 
-    switch(key)
+    switch (key)
     {
       case KSYM_Shift_L:
 	new_modifier = KMOD_Shift_L;
@@ -1739,7 +1754,8 @@ KeyMod GetKeyModStateFromEvents(void)
 
 void StartTextInput(int x, int y, int width, int height)
 {
-#if defined(TARGET_SDL2)
+  textinput_status = TRUE;
+
 #if defined(HAS_SCREEN_KEYBOARD)
   SDL_StartTextInput();
 
@@ -1750,12 +1766,12 @@ void StartTextInput(int x, int y, int width, int height)
     video.shifted_up = TRUE;
   }
 #endif
-#endif
 }
 
 void StopTextInput(void)
 {
-#if defined(TARGET_SDL2)
+  textinput_status = FALSE;
+
 #if defined(HAS_SCREEN_KEYBOARD)
   SDL_StopTextInput();
 
@@ -1766,34 +1782,39 @@ void StopTextInput(void)
     video.shifted_up = FALSE;
   }
 #endif
-#endif
 }
 
-boolean CheckCloseWindowEvent(ClientMessageEvent *event)
+void PushUserEvent(int code, int value1, int value2)
 {
-  if (event->type != EVENT_CLIENTMESSAGE)
-    return FALSE;
+  UserEvent event;
 
-  return TRUE;		/* the only possible message here is SDL_QUIT */
+  SDL_memset(&event, 0, sizeof(event));
+
+  event.type = EVENT_USER;
+  event.code = code;
+  event.value1 = value1;
+  event.value2 = value2;
+
+  SDL_PushEvent((SDL_Event *)&event);
 }
 
 
-/* ========================================================================= */
-/* joystick functions                                                        */
-/* ========================================================================= */
+// ============================================================================
+// joystick functions
+// ============================================================================
 
 void InitJoysticks(void)
 {
   int i;
 
 #if defined(NO_JOYSTICK)
-  return;	/* joysticks generally deactivated by compile-time directive */
+  return;	// joysticks generally deactivated by compile-time directive
 #endif
 
-  /* always start with reliable default values */
+  // always start with reliable default values
   joystick.status = JOYSTICK_NOT_AVAILABLE;
   for (i = 0; i < MAX_PLAYERS; i++)
-    joystick.nr[i] = -1;		/* no joystick configured */
+    joystick.nr[i] = -1;		// no joystick configured
 
   SDLInitJoysticks();
 }
