@@ -21,7 +21,7 @@
 
 #define DEBUG_TAPE_WHEN_PLAYING			FALSE
 
-/* tape button identifiers */
+// tape button identifiers
 #define TAPE_CTRL_ID_EJECT			0
 #define TAPE_CTRL_ID_EXTRA			1
 #define TAPE_CTRL_ID_STOP			2
@@ -33,10 +33,10 @@
 
 #define NUM_TAPE_BUTTONS			8
 
-/* values for tape handling */
+// values for tape handling
 #define TAPE_PAUSE_SECONDS_BEFORE_DEATH		5
 
-/* forward declaration for internal use */
+// forward declaration for internal use
 static void HandleTapeButtons(struct GadgetInfo *);
 static void TapeStopWarpForward(void);
 static float GetTapeLengthSecondsFloat(void);
@@ -44,9 +44,9 @@ static float GetTapeLengthSecondsFloat(void);
 static struct GadgetInfo *tape_gadget[NUM_TAPE_BUTTONS];
 
 
-/* ========================================================================= */
-/* video tape definitions                                                    */
-/* ========================================================================= */
+// ============================================================================
+// video tape definitions
+// ============================================================================
 
 #define VIDEO_INFO_OFF			(VIDEO_STATE_DATE_OFF	|	\
 					 VIDEO_STATE_TIME_OFF	|	\
@@ -98,9 +98,9 @@ static struct GadgetInfo *tape_gadget[NUM_TAPE_BUTTONS];
 #define NUM_TAPE_FUNCTION_STATES	2
 
 
-/* ========================================================================= */
-/* video display functions                                                   */
-/* ========================================================================= */
+// ============================================================================
+// video display functions
+// ============================================================================
 
 static void DrawVideoDisplay_Graphics(unsigned int state, unsigned int value)
 {
@@ -134,7 +134,7 @@ static void DrawVideoDisplay_Graphics(unsigned int state, unsigned int value)
       { -1,					NULL			},
     },
     {
-      /* (no label for displaying optional frame) */
+      // (no label for displaying optional frame)
       { -1,					NULL			},
       { -1,					NULL			},
     },
@@ -160,11 +160,11 @@ static void DrawVideoDisplay_Graphics(unsigned int state, unsigned int value)
     },
   };
 
-  for (k = 0; k < NUM_TAPE_FUNCTION_STATES; k++)	/* on or off states */
+  for (k = 0; k < NUM_TAPE_FUNCTION_STATES; k++)	// on or off states
   {
-    for (i = 0; i < NUM_TAPE_FUNCTIONS; i++)		/* record, play, ... */
+    for (i = 0; i < NUM_TAPE_FUNCTIONS; i++)		// record, play, ...
     {
-      for (j = 0; j < NUM_TAPE_FUNCTION_PARTS; j++)	/* label or symbol */
+      for (j = 0; j < NUM_TAPE_FUNCTION_PARTS; j++)	// label or symbol
       {
 	int graphic = video_pos[i][j].graphic;
 	struct XY *pos = video_pos[i][j].pos;
@@ -186,20 +186,20 @@ static void DrawVideoDisplay_Graphics(unsigned int state, unsigned int value)
 	  if (value == skip_value)
 	    continue;
 
-	  if (k == 1)		/* on */
+	  if (k == 1)		// on
 	  {
 	    gd_bitmap = gfx->bitmap;
 	    gd_x = gfx->src_x;
 	    gd_y = gfx->src_y;
 	  }
-	  else			/* off */
+	  else			// off
 	  {
 	    gd_bitmap = gfx_bg->bitmap;
 	    gd_x = gfx_bg->src_x + pos->x;
 	    gd_y = gfx_bg->src_y + pos->y;
 	  }
 
-	  /* some tape graphics may be undefined -- only draw if defined */
+	  // some tape graphics may be undefined -- only draw if defined
 	  if (gd_bitmap != NULL)
 	    BlitBitmap(gd_bitmap, drawto, gd_x, gd_y, gfx->width, gfx->height,
 		       VX + pos->x, VY + pos->y);
@@ -402,11 +402,11 @@ void DrawCompleteVideoDisplay(void)
 {
   struct GraphicInfo *g_tape = &graphic_info[IMG_BACKGROUND_TAPE];
 
-  /* draw tape background */
+  // draw tape background
   BlitBitmap(g_tape->bitmap, drawto, g_tape->src_x, g_tape->src_y,
 	     gfx.vxsize, gfx.vysize, gfx.vx, gfx.vy);
 
-  /* draw tape buttons (forced) */
+  // draw tape buttons (forced)
   RedrawOrRemapTapeButtons();
 
   DrawVideoDisplay(VIDEO_ALL_OFF, 0);
@@ -461,9 +461,9 @@ void TapeDeactivateDisplayOff(boolean redraw_display)
 }
 
 
-/* ========================================================================= */
-/* tape logging functions                                                    */
-/* ========================================================================= */
+// ============================================================================
+// tape logging functions
+// ============================================================================
 
 static void PrintTapeReplayProgress(boolean replay_finished)
 {
@@ -501,9 +501,9 @@ static void PrintTapeReplayProgress(boolean replay_finished)
 }
 
 
-/* ========================================================================= */
-/* tape control functions                                                    */
-/* ========================================================================= */
+// ============================================================================
+// tape control functions
+// ============================================================================
 
 void TapeSetDateFromEpochSeconds(time_t epoch_seconds)
 {
@@ -547,7 +547,9 @@ void TapeErase(void)
   tape.centered_player_nr_next = -1;
   tape.set_centered_player = FALSE;
 
-  tape.use_mouse = (level.game_engine_type == GAME_ENGINE_TYPE_MM);
+  // set flags for game actions to default values (may be overwritten later)
+  tape.use_key_actions = TRUE;
+  tape.use_mouse_actions = FALSE;
 }
 
 static void TapeRewind(void)
@@ -596,6 +598,10 @@ void TapeStartRecording(int random_seed)
 
   SetDrawDeactivationMask(REDRAW_NONE);
   audio.sound_deactivated = FALSE;
+
+  // required here to update video display if tape door is closed
+  if (GetDoorState() & DOOR_CLOSE_2)
+    OpenDoor(GetDoorState() | DOOR_NO_DELAY | DOOR_FORCE_REDRAW);
 }
 
 static void TapeStartGameRecording(void)
@@ -656,15 +662,15 @@ void TapeStopRecording(void)
   MapTapeEjectButton();
 }
 
-boolean TapeAddAction(byte action[MAX_PLAYERS])
+boolean TapeAddAction(byte action[MAX_TAPE_ACTIONS])
 {
   int i;
 
-  if (tape.pos[tape.counter].delay > 0)		/* already stored action */
+  if (tape.pos[tape.counter].delay > 0)		// already stored action
   {
     boolean changed_events = FALSE;
 
-    for (i = 0; i < MAX_PLAYERS; i++)
+    for (i = 0; i < MAX_TAPE_ACTIONS; i++)
       if (tape.pos[tape.counter].action[i] != action[i])
 	changed_events = TRUE;
 
@@ -680,9 +686,9 @@ boolean TapeAddAction(byte action[MAX_PLAYERS])
       tape.pos[tape.counter].delay++;
   }
 
-  if (tape.pos[tape.counter].delay == 0)	/* store new action */
+  if (tape.pos[tape.counter].delay == 0)	// store new action
   {
-    for (i = 0; i < MAX_PLAYERS; i++)
+    for (i = 0; i < MAX_TAPE_ACTIONS; i++)
       tape.pos[tape.counter].action[i] = action[i];
 
     tape.pos[tape.counter].delay++;
@@ -691,18 +697,18 @@ boolean TapeAddAction(byte action[MAX_PLAYERS])
   return TRUE;
 }
 
-void TapeRecordAction(byte action_raw[MAX_PLAYERS])
+void TapeRecordAction(byte action_raw[MAX_TAPE_ACTIONS])
 {
-  byte action[MAX_PLAYERS];
+  byte action[MAX_TAPE_ACTIONS];
   int i;
 
-  if (!tape.recording)		/* (record action even when tape is paused) */
+  if (!tape.recording)		// (record action even when tape is paused)
     return;
 
-  for (i = 0; i < MAX_PLAYERS; i++)
+  for (i = 0; i < MAX_TAPE_ACTIONS; i++)
     action[i] = action_raw[i];
 
-  if (!tape.use_mouse && tape.set_centered_player)
+  if (tape.use_key_actions && tape.set_centered_player)
   {
     for (i = 0; i < MAX_PLAYERS; i++)
       if (tape.centered_player_nr_next == i ||
@@ -760,14 +766,17 @@ void TapeTogglePause(boolean toggle_mode)
     return;
   }
 
-  if (setup.show_snapshot_buttons &&
-      game_status == GAME_MODE_PLAYING &&
-      CheckEngineSnapshotList())
+  if (game_status == GAME_MODE_PLAYING)
   {
-    if (tape.pausing)
-      MapUndoRedoButtons();
-    else if (!tape.single_step)
-      UnmapUndoRedoButtons();
+    if (setup.show_snapshot_buttons && CheckEngineSnapshotList())
+    {
+      if (tape.pausing)
+	MapUndoRedoButtons();
+      else if (!tape.single_step)
+	UnmapUndoRedoButtons();
+    }
+
+    ModifyPauseButtons();
   }
 }
 
@@ -818,7 +827,7 @@ byte *TapePlayAction(void)
   int update_delay = FRAMES_PER_SECOND / 2;
   boolean update_video_display = (FrameCounter % update_delay == 0);
   boolean update_draw_label_on = ((FrameCounter / update_delay) % 2 == 1);
-  static byte action[MAX_PLAYERS];
+  static byte action[MAX_TAPE_ACTIONS];
   int i;
 
   if (!tape.playing || tape.pausing)
@@ -835,7 +844,7 @@ byte *TapePlayAction(void)
     }
   }
 
-  if (tape.counter >= tape.length)	/* end of tape reached */
+  if (tape.counter >= tape.length)	// end of tape reached
   {
     if (tape.warp_forward && !tape.auto_play)
     {
@@ -867,12 +876,12 @@ byte *TapePlayAction(void)
     DrawVideoDisplaySymbol(state);
   }
 
-  for (i = 0; i < MAX_PLAYERS; i++)
+  for (i = 0; i < MAX_TAPE_ACTIONS; i++)
     action[i] = tape.pos[tape.counter].action[i];
 
 #if DEBUG_TAPE_WHEN_PLAYING
   printf("%05d", FrameCounter);
-  for (i = 0; i < MAX_PLAYERS; i++)
+  for (i = 0; i < MAX_TAPE_ACTIONS; i++)
     printf("   %08x", action[i]);
   printf("\n");
 #endif
@@ -880,7 +889,7 @@ byte *TapePlayAction(void)
   tape.set_centered_player = FALSE;
   tape.centered_player_nr_next = -999;
 
-  if (!tape.use_mouse)
+  if (tape.use_key_actions)
   {
     for (i = 0; i < MAX_PLAYERS; i++)
     {
@@ -1003,7 +1012,7 @@ void TapeQuickSave(void)
     return;
 
   if (tape.recording)
-    TapeHaltRecording();	/* prepare tape for saving on-the-fly */
+    TapeHaltRecording();	// prepare tape for saving on-the-fly
 
   if (TAPE_IS_EMPTY(tape))
   {
@@ -1071,7 +1080,7 @@ void TapeQuickLoad(void)
 
     tape.quick_resume = TRUE;
   }
-  else	/* this should not happen (basically checked above) */
+  else	// this should not happen (basically checked above)
   {
     int reopen_door = (game_status == GAME_MODE_PLAYING ? REQ_REOPEN : 0);
 
@@ -1128,9 +1137,9 @@ boolean PlaySolutionTape(void)
 }
 
 
-/* ------------------------------------------------------------------------- *
- * tape autoplay functions
- * ------------------------------------------------------------------------- */
+// ----------------------------------------------------------------------------
+// tape autoplay functions
+// ----------------------------------------------------------------------------
 
 void AutoPlayTape(void)
 {
@@ -1145,7 +1154,7 @@ void AutoPlayTape(void)
 
   if (autoplay_initialized)
   {
-    /* just finished auto-playing tape */
+    // just finished auto-playing tape
     PrintTapeReplayProgress(TRUE);
 
     num_levels_played++;
@@ -1213,7 +1222,7 @@ void AutoPlayTape(void)
     }
 
 #if 0
-    /* ACTIVATE THIS FOR LOADING/TESTING OF LEVELS ONLY */
+    // ACTIVATE THIS FOR LOADING/TESTING OF LEVELS ONLY
     Print("Level %03d: (only testing level)\n", level_nr);
     continue;
 #endif
@@ -1244,12 +1253,13 @@ void AutoPlayTape(void)
   PrintLine("=", 79);
   Print("Number of levels played: %d\n", num_levels_played);
   Print("Number of levels solved: %d (%d%%)\n", num_levels_solved,
-	 (num_levels_played ? num_levels_solved * 100 / num_levels_played :0));
+	(num_levels_played ? num_levels_solved * 100 / num_levels_played : 0));
   PrintLine("-", 79);
   Print("Summary (for automatic parsing by scripts):\n");
-  Print("LEVELDIR '%s', SOLVED %d/%d (%d%%)",
-	 autoplay_leveldir->identifier, num_levels_solved, num_levels_played,
-	 (num_levels_played ? num_levels_solved * 100 / num_levels_played :0));
+  Print("LEVELDIR [%s] '%s', SOLVED %d/%d (%d%%)",
+	(num_levels_played == num_levels_solved ? " OK " : "WARN"),
+	autoplay_leveldir->identifier, num_levels_solved, num_levels_played,
+	(num_levels_played ? num_levels_solved * 100 / num_levels_played : 0));
 
   if (num_levels_played != num_levels_solved)
   {
@@ -1266,7 +1276,7 @@ void AutoPlayTape(void)
 }
 
 
-/* ---------- new tape button stuff ---------------------------------------- */
+// ---------- new tape button stuff -------------------------------------------
 
 static struct
 {
@@ -1281,7 +1291,7 @@ static struct
     TAPE_CTRL_ID_EJECT,			"eject tape"
   },
   {
-    /* (same position as "eject" button) */
+    // (same position as "eject" button)
     IMG_GFX_TAPE_BUTTON_EXTRA,		&tape.button.eject,
     TAPE_CTRL_ID_EXTRA,			"extra functions"
   },
@@ -1405,9 +1415,6 @@ void RedrawTapeButtons(void)
 
   if (tape.show_game_buttons)
     RedrawGameButtonsOnTape();
-
-  // RedrawGadget() may have set REDRAW_ALL if buttons are defined off-area
-  redraw_mask &= ~REDRAW_ALL;
 }
 
 void RedrawOrRemapTapeButtons(void)
@@ -1483,7 +1490,7 @@ static void HandleTapeButtonsExt(int id)
       }
       else if (tape.pausing)
       {
-	if (tape.playing)			/* PLAY -> PAUSE -> RECORD */
+	if (tape.playing)			// PLAY -> PAUSE -> RECORD
 	  TapeAppendRecording();
 	else
 	  TapeTogglePause(TAPE_TOGGLE_MANUAL);
@@ -1492,7 +1499,7 @@ static void HandleTapeButtonsExt(int id)
       break;
 
     case TAPE_CTRL_ID_PLAY:
-      if (tape.recording && tape.pausing)	/* PAUSE -> RECORD */
+      if (tape.recording && tape.pausing)	// PAUSE -> RECORD
       {
 	// ("TAPE_IS_EMPTY(tape)" is TRUE here -- probably fix this)
 
@@ -1508,25 +1515,25 @@ static void HandleTapeButtonsExt(int id)
       }
       else if (tape.playing)
       {
-	if (tape.pausing)			/* PAUSE -> PLAY */
+	if (tape.pausing)			// PAUSE -> PLAY
 	{
 	  TapeTogglePause(TAPE_TOGGLE_MANUAL | TAPE_TOGGLE_PLAY_PAUSE);
 	}
-	else if (!tape.fast_forward)		/* PLAY -> FFWD */
+	else if (!tape.fast_forward)		// PLAY -> FFWD
 	{
 	  tape.fast_forward = TRUE;
 	}
-	else if (!tape.warp_forward)		/* FFWD -> WARP */
+	else if (!tape.warp_forward)		// FFWD -> WARP
 	{
 	  tape.warp_forward = TRUE;
 	}
-	else if (!tape.deactivate_display)	/* WARP -> WARP BLIND */
+	else if (!tape.deactivate_display)	// WARP -> WARP BLIND
 	{
 	  tape.deactivate_display = TRUE;
 
 	  TapeDeactivateDisplayOn();
 	}
-	else					/* WARP BLIND -> PLAY */
+	else					// WARP BLIND -> PLAY
 	{
 	  tape.fast_forward = FALSE;
 	  tape.warp_forward = FALSE;
