@@ -16,18 +16,18 @@
 #include "game.h"
 
 
-/* for DrawElementShifted */
+// for DrawElementShifted
 #define NO_CUTTING		0
 #define CUT_ABOVE		(1 << 0)
 #define CUT_BELOW		(1 << 1)
 #define CUT_LEFT		(1 << 2)
 #define CUT_RIGHT		(1 << 3)
 
-/* for masking functions */
+// for masking functions
 #define NO_MASKING		0
 #define USE_MASKING		1
  
-/* for MoveDoor */
+// for MoveDoor
 #define DOOR_OPEN_1		(1 << 0)
 #define DOOR_OPEN_2		(1 << 1)
 #define DOOR_CLOSE_1		(1 << 2)
@@ -55,7 +55,7 @@
 #define REDRAW_DOOR_FROM_TOKEN(x)	((x) == DOOR_1 ? REDRAW_DOOR_1 : \
 					 REDRAW_DOOR_2)
 
-/* for Request */
+// for Request
 #define REQ_ASK			(1 << 0)
 #define REQ_CONFIRM		(1 << 1)
 #define REQ_PLAYER		(1 << 2)
@@ -66,8 +66,8 @@
 #define REQUEST_WAIT_FOR_INPUT	(REQ_ASK | REQ_CONFIRM | REQ_PLAYER)
 
 
-int correctLevelPosX_EM(int);
-int correctLevelPosY_EM(int);
+int getFieldbufferOffsetX_RND(int, int);
+int getFieldbufferOffsetY_RND(int, int);
 
 int getLevelFromScreenX(int);
 int getLevelFromScreenY(int);
@@ -86,6 +86,7 @@ void DrawTileCursor(int);
 
 void SetDrawtoField(int);
 void RedrawPlayfield(void);
+void BlitScreenToBitmapExt_RND(Bitmap *, int, int);
 void BlitScreenToBitmap_RND(Bitmap *);
 void BlitScreenToBitmap(Bitmap *);
 void BackToFront(void);
@@ -194,6 +195,7 @@ void ShowEnvelopeDoor(char *text, int);
 void DrawLevel(int);
 void DrawSizedLevel(int, int, int, int, int);
 void DrawMiniLevel(int, int, int, int);
+void DrawPreviewPlayers(void);
 void DrawPreviewLevelInitial(void);
 void DrawPreviewLevelAnimation(void);
 
@@ -216,8 +218,9 @@ void UndrawSpecialEditorDoor(void);
 void CreateToolButtons(void);
 void FreeToolButtons(void);
 
-int map_element_RND_to_EM(int);
-int map_element_EM_to_RND(int);
+int map_element_RND_to_EM_cave(int);
+int map_element_EM_to_RND_cave(int);
+int map_element_EM_to_RND_game(int);
 int map_direction_RND_to_EM(int);
 int map_direction_EM_to_RND(int);
 
@@ -283,7 +286,7 @@ void SetLevelSetInfo(char *, int);
 void ToggleFullscreenOrChangeWindowScalingIfNeeded(void);
 void ChangeViewportPropertiesIfNeeded(void);
 
-boolean CheckIfPlayfieldViewportHasChanged(void);
-boolean CheckIfGlobalBorderOrPlayfieldViewportHasChanged(void);
+boolean CheckIfAllViewportsHaveChanged(void);
+boolean CheckFadeAll(void);
 
-#endif	/* TOOLS_H */
+#endif	// TOOLS_H
